@@ -40,21 +40,13 @@ NULL
 #' @method start nanoListener
 #' @export
 #'
-start.nanoListener <- function(x, ...) {
-
-  invisible(.Call(rnng_listener_start, x))
-
-}
+start.nanoListener <- function(x, ...) invisible(.Call(rnng_listener_start, x))
 
 #' @rdname start
 #' @method start nanoDialer
 #' @export
 #'
-start.nanoDialer <- function(x, async = TRUE, ...) {
-
-  invisible(.Call(rnng_dialer_start, x, async))
-
-}
+start.nanoDialer <- function(x, async = TRUE, ...) invisible(.Call(rnng_dialer_start, x, async))
 
 #' Close Connection
 #'
@@ -89,49 +81,29 @@ NULL
 #' @method close nanoSocket
 #' @export
 #'
-close.nanoSocket <- function(con, ...) {
-
-  invisible(.Call(rnng_close, con))
-
-}
+close.nanoSocket <- function(con, ...) invisible(.Call(rnng_close, con))
 
 #' @rdname close
 #' @method close nanoContext
 #' @export
 #'
-close.nanoContext <- function(con, ...) {
-
-  invisible(.Call(rnng_ctx_close, con))
-
-}
+close.nanoContext <- function(con, ...) invisible(.Call(rnng_ctx_close, con))
 
 #' @rdname close
 #' @method close nanoDialer
 #' @export
 #'
-close.nanoDialer <- function(con, ...) {
-
-  invisible(.Call(rnng_dialer_close, con))
-
-}
+close.nanoDialer <- function(con, ...) invisible(.Call(rnng_dialer_close, con))
 
 #' @rdname close
 #' @method close nanoListener
 #' @export
 #'
-close.nanoListener <- function(con, ...) {
-
-  invisible(.Call(rnng_listener_close, con))
-
-}
+close.nanoListener <- function(con, ...) invisible(.Call(rnng_listener_close, con))
 
 #' @rdname close
 #' @method close nanoStream
 #' @export
 #'
-close.nanoStream <- function(con, ...) {
-
-  invisible(.Call(rnng_stream_close, con))
-
-}
+close.nanoStream <- function(con, ...) invisible(.Call(rnng_stream_close, con))
 
