@@ -35,6 +35,13 @@ SEXP mk_error(const int xc) {
 
 SEXP rnng_serial(SEXP mode) {
 
+  if (TYPEOF(mode) == INTSXP) {
+    switch (INTEGER(mode)[0]) {
+    case 1: return Rf_ScalarLogical(1);
+    default: return Rf_ScalarLogical(0);
+    }
+  }
+
   const char *mod = CHAR(STRING_ELT(mode, 0));
   size_t slen = strlen(mod);
   const char *s = "serial", *r = "raw";
@@ -142,6 +149,8 @@ SEXP rawOneString(unsigned char *bytes, R_xlen_t nbytes, R_xlen_t *np) {
 
 SEXP rnng_matcharg(SEXP mode) {
 
+  if (TYPEOF(mode) == INTSXP) return mode;
+
   const char *mod = CHAR(STRING_ELT(mode, 0));
   size_t slen = strlen(mod);
   const char *s = "serial", *ch = "character", *co = "complex", *d = "double",
@@ -178,6 +187,8 @@ SEXP rnng_matcharg(SEXP mode) {
 
 SEXP rnng_matchargs(SEXP mode) {
 
+  if (TYPEOF(mode) == INTSXP) return mode;
+
   const char *mod = CHAR(STRING_ELT(mode, 0));
   size_t slen = strlen(mod);
   const char *ch = "character", *co = "complex", *d = "double",
