@@ -103,7 +103,15 @@ SEXP rnng_clock(void) {
 
 SEXP rnng_sleep(SEXP msec) {
 
-  nng_msleep((nng_duration) Rf_asInteger(msec));
+  switch (TYPEOF(msec)) {
+  case INTSXP:
+    nng_msleep((nng_duration) INTEGER(msec)[0]);
+    break;
+  case REALSXP:
+    nng_msleep((nng_duration) Rf_asInteger(msec));
+    break;
+  }
+
   return R_NilValue;
 
 }
@@ -628,3 +636,36 @@ SEXP rnng_device(SEXP s1, SEXP s2) {
 
 }
 
+// nano_init -------------------------------------------------------------------
+
+SEXP rnng_matchwarn(SEXP warn) {
+
+  if (TYPEOF(warn) == INTSXP) return warn;
+
+  const char *w = CHAR(STRING_ELT(warn, 0));
+  size_t slen = strlen(w);
+  const char *i = "immediate", *d = "deferred", *e = "error", *n = "none";
+  int xc = 0;
+
+  switch (slen) {
+  case 1:
+  case 2:
+  case 3:
+  case 4:
+    if (!strncmp(n, w, slen)) { xc = -1; break; }
+  case 5:
+    if (!strncmp(e, w, slen)) { xc = 2; break; }
+  case 6:
+  case 7:
+  case 8:
+    if (!strncmp(d, w, slen)) { xc = 0; break; }
+  case 9:
+    if (!strncmp(i, w, slen)) { xc = 1; break; }
+  default:
+      error_return("'warn' should be one of immediate, deferred, error, none");
+  }
+
+  return Rf_ScalarInteger(xc);
+
+}
+
